@@ -247,3 +247,159 @@ COLLECTION_TYPE = {
         }
     }
 }
+
+
+SYMBOLS = {
+    "@",
+    "#",
+    "$",
+    "%",
+    "&",
+    "=",
+    "|",
+    "_",
+    "/",
+    "*",
+    "-",
+    "+"
+}
+PUNCTUATION = {
+    ",",
+    ".",
+    "?",
+    "}",
+    "]",
+    "[",
+    "{",
+    "!",
+    "(",
+    ")"
+}
+NUMBERS = {
+    "0",
+    "1",
+    "2",
+    "3",
+    "4",
+    "5",
+    "6",
+    "7",
+    "8",
+    "9"
+}
+A = {
+    "À",
+    "Á",
+    "Ã",
+    "Â",
+    "à",
+    "á",
+    "ã",
+    "â",
+    "Ä",
+    "ä"
+}
+E = {
+    "È",
+    "É",
+    "Ê",
+    "è",
+    "é",
+    "ê",
+    "Ë",
+    "ë"
+}
+I = {
+    "Ì",
+    "Í",
+    "Î",
+    "ì",
+    "í",
+    "î",
+    "Ï",
+    "i"
+}
+O = {
+    "Ò",
+    "Ó",
+    "Õ",
+    "Ô",
+    "ò",
+    "ó",
+    "õ",
+    "ô",
+    "Ö",
+    "ö"
+}
+U = {
+    "Ù",
+    "Ú",
+    "Û",
+    "ù",
+    "ú",
+    "û",
+    "Ü",
+    "ü"
+}
+C = {
+    "Ç"
+    "ç"
+}
+LOWER_CASE = {
+    "a",
+    "b",
+    "c",
+    "d",
+    "e",
+    "f",
+    "g",
+    "h",
+    "i",
+    "j",
+    "k",
+    "l",
+    "m",
+    "n",
+    "o",
+    "p",
+    "q",
+    "r",
+    "s",
+    "t",
+    "u",
+    "v",
+    "w",
+    "x",
+    "y",
+    "z",
+}
+UPPER_CASE = {
+    "A",
+    "B",
+    "C",
+    "D",
+    "E",
+    "F",
+    "G",
+    "H",
+    "I",
+    "J",
+    "K",
+    "L",
+    "M",
+    "N",
+    "O",
+    "P",
+    "Q",
+    "R",
+    "S",
+    "T",
+    "U",
+    "V",
+    "W",
+    "X",
+    "Y",
+    "Z"
+}
+CHARACTERES = tuple(set([*A,*E,*I,*O,*U,*C,*LOWER_CASE,*UPPER_CASE,SPACE]))
+UPPER_CASE_CHARACTERES = tuple(set([char for char in CHARACTERES if char == char.upper()]))
